@@ -1,7 +1,7 @@
 # FIAIF is an Intelligent firewall
 #
 # Author: Anders Fugmann <afu at fugmann dot net>
-# 
+#
 # FIAIF is an Intelligent firewall
 # Copyright (C) 2002-2011 Anders Peter Fugmann
 #
@@ -21,41 +21,41 @@
 
 ###############################################################################
 # Clear all chains
-# Arguments: 0 for close, 1 for open. 
+# Arguments: 0 for close, 1 for open.
 ###############################################################################
 function iptables_stop ()
 {
     local DEBUG=$1
-    local POLICY 
+    local POLICY
     if (( DEBUG == 0 )); then
 	POLICY=DROP
     else
 	POLICY=ACCEPT
     fi
 
-    echo -n "Clearing all rules: " 
-    IPTABLES -F 
+    echo -n "Clearing all rules: "
+    IPTABLES -F
     IPTABLES -F -t nat
-    IPTABLES -F -t mangle 
+    IPTABLES -F -t mangle
 
-    IPTABLES -X 
-    IPTABLES -X -t nat 
-    IPTABLES -X -t mangle 
+    IPTABLES -X
+    IPTABLES -X -t nat
+    IPTABLES -X -t mangle
 
     IPTABLES -Z
     IPTABLES -Z -t nat
     IPTABLES -Z -t mangle
-    
+
     #Always set default policy.
-    IPTABLES -P INPUT ${POLICY}   
+    IPTABLES -P INPUT ${POLICY}
     IPTABLES -P FORWARD ${POLICY}
     IPTABLES -P OUTPUT ${POLICY}
-    
-    IPTABLES -t nat -P PREROUTING ACCEPT   
+
+    IPTABLES -t nat -P PREROUTING ACCEPT
     IPTABLES -t nat -P POSTROUTING ACCEPT
     IPTABLES -t nat -P OUTPUT ACCEPT
 
-    IPTABLES -t mangle -P PREROUTING ACCEPT   
+    IPTABLES -t mangle -P PREROUTING ACCEPT
     IPTABLES -t mangle -P OUTPUT ACCEPT
     if (( EXTENDED_MANGLE == 1 )); then
 	IPTABLES -t mangle -P INPUT ACCEPT
@@ -63,7 +63,7 @@ function iptables_stop ()
 	IPTABLES -t mangle -P POSTROUTING ACCEPT
     fi
 
-    echo "Done."    
+    echo "Done."
 }
 
 
@@ -73,10 +73,10 @@ function iptables_stop ()
 function setup_default_chains ()
 {
     debug_out "Setting up default chains."
-    local POLICY 
-    local LOG_NAME 
+    local POLICY
+    local LOG_NAME
     local TARGET
-  
+
     LOG_LIMIT=${LOG_LIMIT:=5/min}
     LOG_BURST=${LOG_BURST:=5}
 
@@ -99,7 +99,7 @@ function setup_default_chains ()
 	let ${LOG_LEVEL:=CRIT}
 	LOG="-j LOG --log-level ${LOG_LEVEL} --log-prefix "
     fi
-    
+
     # All DROP targets
     if (( DEBUG == 0 )); then
 	POLICY=DROP
@@ -111,30 +111,30 @@ function setup_default_chains ()
 	IPTABLES -N LOG_${LOG_NAME}_NOLOG
 	if (( VERBOSE == 1 )); then
 	    IPTABLES -A LOG_${LOG_NAME} -j LIMIT_LOGGING_${POLICY}
-	    IPTABLES -A LOG_${LOG_NAME} ${LOG} "[${LOG_PREFIX}${LOG_NAME}]:" 
+	    IPTABLES -A LOG_${LOG_NAME} ${LOG} "[${LOG_PREFIX}${LOG_NAME}]:"
 	fi
 	IPTABLES -A LOG_${LOG_NAME} -j ${POLICY}
 	IPTABLES -A LOG_${LOG_NAME}_NOLOG -j ${POLICY}
     done
-    
+
     # All REJECT targets
     if (( DEBUG == 0 )); then
 	POLICY=REJECT
     else
 	POLICY=ACCEPT
     fi
-    
+
     for LOG_NAME in ${LOG_REJECT_TARGETS}; do
 	IPTABLES -N LOG_${LOG_NAME}
 	IPTABLES -N LOG_${LOG_NAME}_NOLOG
 	if (( VERBOSE == 1 )); then
 	    IPTABLES -A LOG_${LOG_NAME} -j LIMIT_LOGGING_${POLICY}
-	    IPTABLES -A LOG_${LOG_NAME} ${LOG} "[${LOG_PREFIX}${LOG_NAME}]:" 
+	    IPTABLES -A LOG_${LOG_NAME} ${LOG} "[${LOG_PREFIX}${LOG_NAME}]:"
 	fi
 	IPTABLES -A LOG_${LOG_NAME} -j ${POLICY}
 	IPTABLES -A LOG_${LOG_NAME}_NOLOG -j ${POLICY}
     done
-	  
+
     # All ACCEPT targets (Never log.)
     for LOG_NAME in ${LOG_ACCEPT_TARGETS}; do
 	IPTABLES -N LOG_${LOG_NAME}
@@ -159,7 +159,7 @@ function setup_default_chains ()
     else
 	POLICY=ACCEPT
     fi
-    IPTABLES -N NOLOG_DROP 
+    IPTABLES -N NOLOG_DROP
     IPTABLES -A NOLOG_DROP -j ${POLICY}
 
     # Make reserved chain
@@ -243,16 +243,16 @@ function chain_redirect ()
     local DEVICE
     local PARAM
 
-    IPTABLES -N GENERAL 
+    IPTABLES -N GENERAL
     IPTABLES -A GENERAL -j SANITY
-    IPTABLES -A GENERAL -m state --state RELATED,ESTABLISHED -j LOG_ACCEPT
+    IPTABLES -A GENERAL -m conntrack --ctstate RELATED,ESTABLISHED -j LOG_ACCEPT
     # We only examine new packets.
     IPTABLES -A GENERAL -j CHECK_IP
 
     for CHAIN in ${BUILT_IN_CHAINS_filter}; do
 	IPTABLES -N ${CHAIN}_NEW
 	IPTABLES -A ${CHAIN} -j GENERAL
-	IPTABLES -A ${CHAIN} -m state --state NEW -j ${CHAIN}_NEW
+	IPTABLES -A ${CHAIN} -m conntrack --ctstate NEW -j ${CHAIN}_NEW
 	IPTABLES -A ${CHAIN} -j LOG_GLOBAL_MISS
 
 	for DEVICE in ${DEVICE_LIST}; do
@@ -267,12 +267,12 @@ function chain_redirect ()
 	    esac
 
 	    IPTABLES -A ${CHAIN}_NEW ${PARAM} -j ${CHAIN}_NEW_${DEVICE}
-	done	    
+	done
     done
 
     if kernel_version_ge 2.4.21; then
         debug_out "Enable traceroute workarround:"
-	IPTABLES -I OUTPUT -p ICMP -m state --state INVALID --icmp-type 11 \
+	IPTABLES -I OUTPUT -p ICMP -m conntrack --ctstate INVALID --icmp-type 11 \
 	    -j OUTPUT_NEW
     fi
 
@@ -286,16 +286,16 @@ function chain_redirect ()
 
 ###############################################################################
 # set_tos
-# Params: TOS protocol ports   
+# Params: TOS protocol ports
 ###############################################################################
-function set_tos () 
+function set_tos ()
 {
     local CHAIN=$1
     local TOS=$2
     local PROTOCOL=$3
     local PORTS=$4
-    
-    if [[ -n "${PORTS}" ]]; then 
+
+    if [[ -n "${PORTS}" ]]; then
 	local PORTS_PARAM=""
 	if [[ "${PORTS}" == "any" || "${PORTS}" == "ANY" ]]; then
 	    IPTABLES -t mangle -A ${CHAIN} -p ${PROTOCOL} \
@@ -309,14 +309,14 @@ function set_tos ()
 		    -m multiport --dports ${PORTS} -j TOS --set-tos ${TOS}
 		IPTABLES -t mangle -A ${CHAIN} -p ${PROTOCOL} \
 		    -m multiport --sports ${PORTS} -j TOS --set-tos ${TOS}
-		
+
 	    fi
 	fi
     fi
 }
 
 ###############################################################################
-# Read TOS_FILE, and call set_tos   
+# Read TOS_FILE, and call set_tos
 ###############################################################################
 function read_tos()
 {
@@ -352,18 +352,18 @@ function read_tos()
 
 
 ###############################################################################
-# Setup zone LO. This zone is so specialized, 
+# Setup zone LO. This zone is so specialized,
 # so who would change rules on this.
 # I still believe that the loopback interface is weired.
 ###############################################################################
 function configure_zone_lo ()
 {
     debug_out "Configuring zone: LO"
-    
+
     #Do not allow forwarding.
     IPTABLES -A FORWARD -o lo -j LOG_DROP
-    IPTABLES -A FORWARD -i lo -j LOG_DROP    
-    
+    IPTABLES -A FORWARD -i lo -j LOG_DROP
+
     # Accept any packets.
     IPTABLES -A INPUT -i lo -j ACCEPT
 
@@ -374,15 +374,15 @@ function configure_zone_lo ()
 
 ###############################################################################
 # State valid:
-# returns 1, if the state file is valid. 
+# returns 1, if the state file is valid.
 ###############################################################################
 function state_valid()
 {
-    if [[ ! -f ${FIAIF_STATE_FILE} ]]; then 
+    if [[ ! -f ${FIAIF_STATE_FILE} ]]; then
 	return 2
     fi
 
-    if [[ ${FIAIF_STATE_FILE} -ot ${CONF_FILE} || 
+    if [[ ${FIAIF_STATE_FILE} -ot ${CONF_FILE} ||
           ${FIAIF_STATE_FILE} -ot ${CONF_DIR}/${RESERVED_NETS} || \
           ${FIAIF_STATE_FILE} -ot ${CONF_DIR}/${PRIVATE_NETS}  || \
           ${FIAIF_STATE_FILE} -ot ${CONF_DIR}/${TOS_FILE} || \
@@ -430,7 +430,7 @@ function test_zone ()
     awk -v "ZONES=${ZONE_LIST}" \
 	-f ${FIAIF_SHARED}/syntax.awk \
 	-f ${FIAIF_SHARED}/zone_rules.awk < ${ZONE_FILE} > ${TMP_FILE}
-    
+
     if (( $? != 0 )); then
 	# We found an error.
 	print_err "Syntax check for zone ${ZONE} failed. See errors below."
@@ -439,7 +439,7 @@ function test_zone ()
 	done
 	AVAILABLE=0
     else
-	# Try reading the zone. 
+	# Try reading the zone.
 	read_zone ${ZONE}
 	if (( $? != 0 )); then
 	    print_err "Warning: Device for ${ZONE} is not up."
@@ -456,14 +456,14 @@ function test_zone ()
 ###############################################################################
 function iptables_setup ()
 {
-    # Damn bash. We really needed this to be in a seperate function, 
+    # Damn bash. We really needed this to be in a seperate function,
     # but declare only declares locally to functions.
     local GLOBAL_INTERFACES=""
     local DYNAMIC_INTERFACES=""
     DEVICE_LIST=""
 
     local DEVICE
-    for ZONE in ${ZONES}; do	
+    for ZONE in ${ZONES}; do
 	# Test the zone file.
 	test_zone ${ZONE}
 	if (( $? == 0 )); then
@@ -475,10 +475,10 @@ function iptables_setup ()
 	    declare -ri ${ZONE}_DYNAMIC="${DYNAMIC}"
 	    declare -r ${ZONE}_BCAST="${BCAST}"
 	    declare -ri ${ZONE}_GLOBAL="${GLOBAL}"
-	    declare -r ${ZONE}_NETS="${NET} ${NET_EXTRA}" 
-	    declare -r ${ZONE}_IPS="${IP} ${IP_EXTRA}" 
+	    declare -r ${ZONE}_NETS="${NET} ${NET_EXTRA}"
+	    declare -r ${ZONE}_IPS="${IP} ${IP_EXTRA}"
 	    declare -ri ${ZONE}_AVAILABLE="1"
-	    
+
 	    # Make sure that only one DYNAMIC/GLOBAL zone per interface.
 	    local IFACE
 	    for IFACE in ${GLOBAL_INTERFACES} ${DYNAMIC_INTERFACES}; do
@@ -491,7 +491,7 @@ function iptables_setup ()
 			print_err "Error: Zone ${ZONE} covers interface ${DEV}, but a zone definition already exists"
 			print_err "for ${DEV}, which is declared GLOBAL or DYNAMIC."
 		    fi
-    		    declare ${ZONE}_AVAILABLE="0"		
+    		    declare ${ZONE}_AVAILABLE="0"
 		    let DEV_ERRORS++
 		fi
 	    done
@@ -501,28 +501,28 @@ function iptables_setup ()
 	    if (( AVAILABLE == 0 )); then
 		continue;
 	    fi
-	    
+
 	    if (( GLOBAL == 1 )); then
 		GLOBAL_INTERFACES="${GLOBAL_INTERFACES} ${DEV}"
 	    fi
 	    if (( DYNAMIC == 1 )); then
 		DYNAMIC_INTERFACES="${DYNAMIC_INTERFACES} ${DEV}"
 	    fi
-	    
+
 	    # Create a device-based list
 	    for DEVICE in ${DEVICE_LIST}; do
-		if [[ "${DEVICE}" == "${DEV}" ]]; then 
+		if [[ "${DEVICE}" == "${DEV}" ]]; then
 		    break
 		fi
 	    done
 
 	    if [[ "${DEVICE}" != "${DEV}" ]]; then
 		DEVICE_LIST="${DEVICE_LIST} ${DEV}"
-	    fi	
-	    
+	    fi
+
 	    # Create zone specific chains.
 	    zone_chains ${ZONE}
-	    
+
 	fi
     done
     # Setup default global chains.
@@ -530,10 +530,10 @@ function iptables_setup ()
 
     # Set TOS values
     read_tos
-    
+
     # Configure the loopback device.
     configure_zone_lo
-    
+
     # Setup chain redirection.
     chain_redirect
 
@@ -554,7 +554,7 @@ function iptables_setup ()
 	    configure_zone ${ZONE}
 	fi
     done
-    echo 
+    echo
 
     debug_out "Log martians"
     for DEVICE in ${DEVICE_LIST}; do
