@@ -3,7 +3,7 @@
 # description: Automates a packet filtering firewall with iptables.
 #
 # Script Author: Anders Fugmann <afu at fugmann dot net>
-# 
+#
 # FIAIF is an Intelligent firewall
 # Copyright (C) 2002-2011 Anders Peter Fugmann
 #
@@ -22,7 +22,7 @@
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 ###############################################################################
-# Filter out illegal packets. 
+# Filter out illegal packets.
 # Parameters: <queue> <table>
 ###############################################################################
 function add_sanity_check()
@@ -30,15 +30,15 @@ function add_sanity_check()
     local TABLE=$1
     local QUEUE=$2
 
-    IPTABLES -t ${TABLE} -A ${QUEUE} -m state --state INVALID -j LOG_INVALID
+    IPTABLES -t ${TABLE} -A ${QUEUE} -m conntrack --ctstate INVALID -j LOG_INVALID
 
-    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL ACK -m state --state ESTABLISHED -j RETURN
-    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL ACK -m state --state NEW,RELATED -j LOG_SCAN
-    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL SYN -m state --state NEW -j RETURN
-    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL SYN -m state --state RELATED -j RETURN
-    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL PSH,ACK -m state --state ESTABLISHED -j RETURN
-    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL PSH,ACK -m state --state NEW -j RETURN
-    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL PSH,ACK -m state --state RELATED -j LOG_SCAN
+    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL ACK -m conntrack --ctstate ESTABLISHED -j RETURN
+    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL ACK -m conntrack --ctstate NEW,RELATED -j LOG_SCAN
+    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL SYN -m conntrack --ctstate NEW -j RETURN
+    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL SYN -m conntrack --ctstate RELATED -j RETURN
+    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL PSH,ACK -m conntrack --ctstate ESTABLISHED -j RETURN
+    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL PSH,ACK -m conntrack --ctstate NEW -j RETURN
+    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL PSH,ACK -m conntrack --ctstate RELATED -j LOG_SCAN
     IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL NONE -j LOG_SCAN
     IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL ALL -j LOG_SCAN
     IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags SYN,FIN SYN,FIN -j LOG_SCAN
@@ -50,28 +50,28 @@ function add_sanity_check()
     IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ACK,FIN FIN -j LOG_SCAN
     IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ACK,PSH PSH -j LOG_SCAN
     IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ACK,URG URG -j LOG_SCAN
-    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL RST -m state --state ESTABLISHED -j RETURN
-    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL RST -m state --state NEW,RELATED -j LOG_SCAN
+    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL RST -m conntrack --ctstate ESTABLISHED -j RETURN
+    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL RST -m conntrack --ctstate NEW,RELATED -j LOG_SCAN
     IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags SYN,ACK NONE -j LOG_SCAN
-    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL SYN -m state --state NEW -j RETURN
-    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL SYN -m state --state RELATED -j RETURN
+    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL SYN -m conntrack --ctstate NEW -j RETURN
+    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL SYN -m conntrack --ctstate RELATED -j RETURN
     ## This seems to conservative....
-    # IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL SYN -m state --state ESTABLISHED -j LOG_SCAN
-    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL SYN,ACK -m state --state ESTABLISHED -j RETURN
-    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL SYN,ACK -m state --state NEW,RELATED -j LOG_SCAN
-    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL FIN,ACK -m state --state ESTABLISHED -j RETURN
-    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL FIN,ACK -m state --state NEW,RELATED -j LOG_SCAN_NOLOG
-    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL ACK,PSH,RST -m state --state ESTABLISHED -j RETURN
-    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL ACK,PSH,RST -m state --state NEW,RELATED -j LOG_SCAN
-    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL FIN,PSH,ACK -m state --state ESTABLISHED -j RETURN
-    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL FIN,PSH,ACK -m state --state NEW,RELATED -j LOG_SCAN
+    # IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL SYN -m conntrack --ctstate ESTABLISHED -j LOG_SCAN
+    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL SYN,ACK -m conntrack --ctstate ESTABLISHED -j RETURN
+    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL SYN,ACK -m conntrack --ctstate NEW,RELATED -j LOG_SCAN
+    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL FIN,ACK -m conntrack --ctstate ESTABLISHED -j RETURN
+    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL FIN,ACK -m conntrack --ctstate NEW,RELATED -j LOG_SCAN_NOLOG
+    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL ACK,PSH,RST -m conntrack --ctstate ESTABLISHED -j RETURN
+    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL ACK,PSH,RST -m conntrack --ctstate NEW,RELATED -j LOG_SCAN
+    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL FIN,PSH,ACK -m conntrack --ctstate ESTABLISHED -j RETURN
+    IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL FIN,PSH,ACK -m conntrack --ctstate NEW,RELATED -j LOG_SCAN
 
-    #IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL RST,ACK,PSH -j LOG_SCAN 
+    #IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL RST,ACK,PSH -j LOG_SCAN
     #IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL RST,ACK,URG -j LOG_SCAN
     #IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL RST,ACK,PSH,URG -j LOG_SCAN
     #IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL FIN,PSH,ACK,URG -j LOG_SCAN
     #IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL ACK,URG -j LOG_SCAN
-    #IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL ACK,URG,FIN -j LOG_SCAN 
+    #IPTABLES -t ${TABLE} -A ${QUEUE} -p tcp --tcp-flags ALL ACK,URG,FIN -j LOG_SCAN
 
     ### ICMP TESTS
     IPTABLES -t ${TABLE} -A ${QUEUE} -p icmp --fragment -j LOG_DROP
